# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog],
and this project adheres to [Semantic Versioning].

## [Unreleased]

## [0.5.3] - 2024-05-21
- add snowflake port into AppConfig, default at 3004

## [0.5.2] - 2024-04-05
- Prune some unused settings from AppConfig (launch bools and batching settings)

## [0.5.1] - 2024-03-19

- a minor fix for cross-platform release in github ci

## [0.5.0] - 2024-03-19

- support cross-platform release for takeoff-config package

## [0.4.0] - 2024-03-08

- First versioned release of takeoff-config, with a new release process that pushes takeoff-config to pypi alongside takeoff-client with the same version [PR 1079](https://github.com/TNBase/pantheon/pull/1079)
